@@ -27,6 +27,22 @@ array_sort: Final = (
     f" LANGUAGE SQL "
     f" IMMUTABLE;")
 
+# @ref https://stackoverflow.com/questions/3994556/eliminate-duplicate-array-values-in-postgres
+array_sort_unique: Final = (
+    f" CREATE OR REPLACE FUNCTION "
+    f" {CFn.array_sort_unique} (ANYARRAY) "
+    f" RETURNS ANYARRAY "
+    f" AS"
+    f" $$"
+    f"   SELECT ARRAY( "
+    f"     SELECT DISTINCT $1[s.i]  "
+    f"     FROM generate_series(array_lower($1,1), array_upper($1,1)) AS s(i)  "
+    f"     ORDER BY 1  "
+    f"               );"
+    f" $$ "
+    f" LANGUAGE SQL "
+    f" IMMUTABLE;")
+
 if_null_2_empty_bigint_array: Final = (
     f" CREATE OR REPLACE FUNCTION "
     f" {CFn.if_null_2_empty_bigint_array} ("
@@ -50,4 +66,5 @@ if_null_2_empty_bigint_array: Final = (
 def insert_util_fn__general(conn):
     insert_function(is_null, CFn.is_null, conn)
     insert_function(array_sort, CFn.array_sort, conn)
+    insert_function(array_sort_unique, CFn.array_sort_unique, conn)
     insert_function(if_null_2_empty_bigint_array, CFn.if_null_2_empty_bigint_array, conn)
