@@ -16,9 +16,9 @@ class FnHttpStatusErrorCodeOnly(AJsonPlPgSqlFunction):
     def body(self) -> str:
         return (
             f" {Arg.result} := {BFn.jsonb_build_object}("
-            f"    '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
+            f"     '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
             f"    '{CA.___Error___}', {BFn.jsonb_build_object}("
             f"      '{CA.Code}', ({Arg.input}->>'{CA.Code}')::INT"
             f"    )" 
-            f"  )"
+            f" );"
         )
\ No newline at end of file
