@@ -108,7 +108,7 @@ fn_jsonb_array_2_text_array: Final = (
 
 fn_jsonb_2_jsonb_array: Final = (
     f" CREATE OR REPLACE FUNCTION "
-    f" {CFn.fn_jsonb_2_jsonb_array} (JSONB) "
+    f" {CFn.jsonb_2_jsonb_array} (JSONB) "
     f" RETURNS JSONB[] "
     f" AS $$ "
     f"   SELECT array_agg(x)::JSONB[] || ARRAY[]::JSONB[] FROM {BFn.jsonb_array_elements}($1) t(x);"
